@@ -37,7 +37,7 @@ GetOptions(
         straatnaam|street=s
         postcode|postalCode=s
         huisnummer|houseNumber=s
-        plaats|woonplaats|city=s
+        plaats|woonplaats|stad|city=s
         type=s
         InclusiefInactieveRegistraties|inactief|inactive
         pagina=i
@@ -105,7 +105,7 @@ query_kvk.pl - Query the Dutch Chamber of Commerce via the CLI
 
 =head1 VERSION
 
-version 0.100
+version 0.101
 
 =head1 SYNOPSIS
 
@@ -117,7 +117,7 @@ Query the Kamer van Koophandel API via the command line. This tool supports all
 the calls that the KvK has made publicly available. By default you can search
 the KvK if you provide search terms.
 
-Please see L<the KvK developer page|https://developer.kvk.nl> for more
+Please see L<the KvK developer page|https://developers.kvk.nl> for more
 information on how to use the API.
 
 =head1 NAME
